function [Num_subarrays_mat, Ntx_subarrays_mat] = create_subarrays(U, Ntx_range, K_range)
% Author: Natasha Birari, natashabirari@gmail.com, Aug 2022
%
% Function to create the sub-array structures for given number of users.
% K = number of antenna elements per sub-array
% Q = number of sub-arrays = number of RF chains = M
% K*Q = K*M = Ntx
%
% This code is based on the assumption that number of subarrays Q equals
% the number of users U. The subarray structures created by this code are 
% intended for 8, 16 or 32 users. It will need adjustments for 
% > 32 users.
%
% INPUT: 
% U         : number of users, scalar choice of {8,16,32}
% Ntx_range : range of possible Ntx values, row vector
% K_range   : range of possible K values
%
% OUTPUT:
% Num_subarrays_mat : matrix of number of feasible subarray sizes
% Ntx_subarrays_mat : matrix of corresponding number of antennas for Num_subarrays_mat
    
    % total antennas
    ntx = Ntx_range;
    
    % number of sub-arrays = antennas total/ antennas per subarray
    for i = 1:length(K_range)
       Num_subarrays_mat(i,:) = ntx./K_range(i);
    end
    
    % remove fractional values
    Num_subarrays_mat(rem(Num_subarrays_mat,2) ~= 0) = 0;
    
    % meet minimum number of subarrays = number of users
    Num_subarrays_mat(Num_subarrays_mat<U) = 0;
    
    % get Ntx corresponding to number of sub-arrays for given num. users
    Ntx_subarrays_mat = K_range'.*Num_subarrays_mat;

end