function output_plot = plotSingleBarsPdc(breakdown_data, total_data, comp_names, Ntx_range, N_user, yl)
% Author: Natasha Birari, natashabirari@gmail.com, Aug 2022
%
% This function plots the system power consumption (including component breakdown)
% of non-subarray type architectures, with varying total number of transmit
% antennas (i.e. 1 single bar per value of Ntx)
%
% INPUT:
% breakdown_data : system power consumption breakdown per component, matrix
% total_data : total system power consumption, vector
% comp_names : names of the components whose contribution is to be plotted
% Ntx_range : range of Ntx values for x-axis
% N_user    : number of users
% yl        : y-axis limit
%
% OUTPUT:
% output_plot : figure

breakdown_data = breakdown_data/1000;         % mW -> W
total_data = total_data/1000;                 % mW -> W

% choose bar colors based on number of components being plotted
barcolors = colormap(flipud(parula(length(comp_names{1}))));        
%barcolors(end,:) = [0.9 0 0.1];   % for jet colormap

% define x axis
xx = 1:length(Ntx_range);

output_plot = figure; hold on;
% plot component breakdown of P_dc
bp = bar(xx, breakdown_data', 0.45, 'stacked', 'FaceColor', "flat");
% change colours
for j = 1:length(bp)
    set(bp(j), 'FaceColor', barcolors(j,:));
end
% plot total P_dc as a lineplot - commented out for better visibility
% plot(xx, total_dat, 'k-O','LineWidth', 1); 
hold off;
% check for specified y-axis limit, otherwise choose one based on expected
% max value of P_dc
if isnumeric(yl)
    ylim([0 yl]);
else
    if N_user > 30
        ylim([0 800]); 
    elseif N_user < 8
        ylim([0 100]);
    else
        ylim([0 400]); 
    end
end
% Set axis properties
ax = gca;
ax.FontSize = 11;
ylabel("Total Power Comsumption [W]", 'FontSize',13); 
xlabel('N_{TX}'); 
%xticks(xx); xticklabels({'16','32','64','128','256','384','512'}); 
xticks(xx); xticklabels({'16','32','64','128','256','512'}); 
legend(comp_names{1}(1:end),'Location','NE'); 
grid on; box on;
end