function [myvec_idxs, fidx, ntx_selected, P_tot_vec, P_br_vec, txt] = select_subarrays(arch_P_tot,arch_P_tot_breakdown_cell, arch, N_user, Ntx_range, K_range, N_user_range)
% Author: Natasha Birari, natashabirari@gmail.com, Aug 2022
% 
% This function plots only those subarray configs where the number of RF
% chains is equal to the number of users. 
% Therefore it becomes a Single Stacked Bar Graph plot with one bar per 
% Ntx value, instead of multiple bars per Ntx value
%
% NOTE: indices are HARD CODED for now in array pos0_mat

if arch == "SDMBA"
        % Do not plot the case of K = 32 for SDMBA because the power consumption was too
        % high --> set as NaN.
        arch_P_tot(K_range == 32,:) = NaN;
        arch_P_tot_breakdown_cell{K_range == 32}(:) = NaN;
end

% hardcoded positions
pos0 = [3 1; 2 1; 1 1; 1 2; 1 3]; 

% get starting positions indices
i0 = pos0(N_user_range == N_user, 1);   % row idx
j0 = pos0(N_user_range == N_user, 2);   % col idx


i = i0; j = j0; count = 1;             % initialise
myvec_idxs = [];                       % preallocate

% Get feasible pairs of (K, Ntx)
while i <= length(K_range) && j <= length(Ntx_range)
    myvec_idxs(:,count) = [i;j];            % save values of K; Ntx
    i = i + 1; j = j+1; count = count+1;    % next position
end

fidx = NaN*Ntx_range;               % get NaN array of same size as Ntx_range
fidx(myvec_idxs(2,:)) = 1;          % convert pairs to array

k_txt = K_range(myvec_idxs(1,:));   % store K values for plot
ntx_selected = Ntx_range.*fidx;     % store feasible Ntx values

P_dat = [];                         % get Pdc values of selected (K, Ntx) pairs
for ii = 1:length(myvec_idxs)
     idc = myvec_idxs(:,ii);
     P_dat(ii) = arch_P_tot(idc(1),idc(2));

     P_dat_br_k = arch_P_tot_breakdown_cell{idc(1)};  % first, select K
     P_dat_br_n(:,ii) = P_dat_br_k(:,idc(2));               % then, select Ntx 
end
 
% set spacing for conversion to array of size Ntx_range
len_br_n = length(P_dat_br_n);
pre = j0 - 1;                                   
post = length(Ntx_range) - length(P_dat) - pre;
 
P_tot_vec = [NaN*ones(1,pre) P_dat NaN*ones(1,post)]*1000;     % W -> mW
P_br_vec = [NaN*ones(len_br_n,pre) P_dat_br_n NaN*ones(len_br_n,post)];  % in mW already
txt = [NaN*ones(1,pre) k_txt NaN*ones(1,post)];         % for labelling

end